@@ -23,12 +23,13 @@ using namespace boost;
 using namespace graph_tool;
 
 void generate_knn(GraphInterface& gi, boost::python::object om, size_t k,
-                  double r, double epsilon, bool cache, boost::any aw,
-                  rng_t& rng)
+                  double r, size_t max_rk, double epsilon, bool local,
+                  boost::any aw, bool verbose,  rng_t& rng)
 
 {
     typedef eprop_map_t<double>::type emap_t;
     auto w = any_cast<emap_t>(aw);
+    adj_list<> h(gi.get_num_vertices());
 
     try
     {
@@ -45,59 +46,33 @@ void generate_knn(GraphInterface& gi, boost::python::object om, size_t k,
                 return sqrt(d);
             };
 
-        if (!cache)
-        {
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         gen_knn<true>(g, d_e, k, r, epsilon, w, rng);
-                     })();
-        }
-        else
-        {
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         auto d = make_cached_dist(g, d_e);
-                         gen_knn<true>(g, d, k, r, epsilon, w, rng);
-                     })();
-        }
+        run_action<always_directed_never_filtered_never_reversed>()
+            (gi, [&](auto& g)
+                 {
+                     if (local)
+                         gen_knn_local<true>(g, d_e, k, r, epsilon, w, verbose, rng);
+                     else
+                         gen_knn<true>(g, d_e, k, r, max_rk, epsilon, w, h, verbose, rng);
+                 })();
     }
     catch (InvalidNumpyConversion&)
     {
-        if (!cache)
-        {
-            auto d_e =
-                [&](auto v, auto u)
-                {
-                    double d = python::extract<double>(om(v, u));
-                    return d;
-                };
+        auto d_e =
+            [&](auto v, auto u)
+            {
+                double d;
+                d = python::extract<double>(om(v, u));
+                return d;
+            };
 
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         gen_knn<false>(g, d_e, k, r, epsilon, w, rng);
-                     })();
-        }
-        else
-        {
-            auto d_e =
-                [&](auto v, auto u)
-                {
-                    double d;
-                    #pragma omp critical
-                    d = python::extract<double>(om(v, u));
-                    return d;
-                };
-
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         auto d = make_cached_dist(g, d_e);
-                         gen_knn<true>(g, d, k, r, epsilon, w, rng);
-                     })();
-        }
+        run_action<always_directed_never_filtered_never_reversed>()
+            (gi, [&](auto& g)
+                 {
+                     if (local)
+                         gen_knn_local<false>(g, d_e, k, r, epsilon, w, verbose, rng);
+                     else
+                         gen_knn<false>(g, d_e, k, r, max_rk, epsilon, w, h, verbose, rng);
+                 })();
     }
 }
 
@@ -145,12 +120,13 @@ void generate_knn_exact(GraphInterface& gi, boost::python::object om, size_t k,
 }
 
 void generate_k_nearest(GraphInterface& gi, boost::python::object om, size_t k,
-                        double r, double epsilon, bool cache, boost::any aw,
-                        bool directed, rng_t& rng)
+                        double r, size_t max_rk, double epsilon, boost::any aw,
+                        bool local, bool directed, bool verbose, rng_t& rng)
 
 {
     typedef eprop_map_t<double>::type emap_t;
     auto w = any_cast<emap_t>(aw);
+    adj_list<> h(gi.get_num_vertices());
 
     try
     {
@@ -162,63 +138,29 @@ void generate_k_nearest(GraphInterface& gi, boost::python::object om, size_t k,
                 return euclidean(u, v, m);
             };
 
-        if (!cache)
-        {
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         gen_k_nearest<true>(g, d_e, k, r, epsilon, w, directed,
-                                             rng);
-                     })();
-        }
-        else
-        {
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         auto d = make_cached_dist(g, d_e);
-                         gen_k_nearest<true>(g, d, k, r, epsilon, w, directed,
-                                             rng);
-                     })();
-        }
+        run_action<always_directed_never_filtered_never_reversed>()
+            (gi, [&](auto& g)
+                 {
+                     gen_k_nearest<true>(g, d_e, k, r, max_rk, epsilon, w, h, local,
+                                         directed, verbose, rng);
+                 })();
     }
     catch (InvalidNumpyConversion&)
     {
-        if (!cache)
-        {
-            auto d_e =
-                [&](auto v, auto u)
-                {
-                    double d = python::extract<double>(om(v, u));
-                    return d;
-                };
+        auto d_e =
+            [&](auto v, auto u)
+            {
+                double d;
+                d = python::extract<double>(om(v, u));
+                return d;
+            };
 
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         gen_k_nearest<false>(g, d_e, k, r, epsilon, w,
-                                              directed, rng);
-                     })();
-        }
-        else
-        {
-            auto d_e =
-                [&](auto v, auto u)
-                {
-                    double d;
-                    #pragma omp critical
-                    d = python::extract<double>(om(v, u));
-                    return d;
-                };
-
-            run_action<always_directed_never_filtered_never_reversed>()
-                (gi, [&](auto& g)
-                     {
-                         auto d = make_cached_dist(g, d_e);
-                         gen_k_nearest<true>(g, d, k, r, epsilon, w, directed,
-                                             rng);
-                     })();
-        }
+        run_action<always_directed_never_filtered_never_reversed>()
+            (gi, [&](auto& g)
+                 {
+                     gen_k_nearest<false>(g, d_e, k, r, max_rk, epsilon, w, h, local,
+                                          directed, verbose, rng);
+                 })();
     }
 }
 
