@@ -107,21 +107,21 @@ python::object overlap_mcmc_sweep_parallel(python::object omcmc_states,
         overlap_block_state::dispatch(oblock_states[i], dispatch);
     }
 
-    parallel_rng<rng_t>::init(rng);
+    parallel_rng<rng_t> prng(rng);
 
     std::vector<std::tuple<double, size_t, size_t>> rets(N);
 
     #pragma omp parallel for schedule(runtime)
     for (size_t i = 0; i < N; ++i)
     {
-        auto& rng_ = parallel_rng<rng_t>::get(rng);
+        auto& rng_ = prng.get(rng);
         rets[i] = sweeps[i]->run(rng_);
     }
 
     python::list orets;
     for (auto& ret : rets)
         orets.append(tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret));
-    return std::move(orets);
+    return orets;
 }
 
 #define __MOD__ inference
