@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -15,22 +15,15 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-#include "graph.hh"
+
+#define __MOD__ layout
+#define DEF_REGISTRY
+#include "module_registry.hh"
+
 #include <boost/python.hpp>
-
 using namespace boost::python;
-void export_arf();
-void export_fruchterman_reingold();
-void export_sfdp();
-void export_radial();
-void export_planar();
-
 BOOST_PYTHON_MODULE(libgraph_tool_layout)
 {
     docstring_options dopt(true, false);
-    export_arf();
-    export_fruchterman_reingold();
-    export_sfdp();
-    export_radial();
-    export_planar();
+    __MOD__::EvokeRegistry();
 }
