@@ -19,17 +19,19 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.clustering`` - Clustering coefficients
----------------------------------------------------
+``graph_tool.clustering``
+=========================
 
-Provides algorithms for calculation of clustering coefficients,
-aka. transitivity.
+
+This module provides algorithms for calculation of clustering coefficients,
+a.k.a. transitivity, and related concepts.
 
 Summary
 +++++++
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    local_clustering
    global_clustering
@@ -37,8 +39,6 @@ Summary
    motifs
    motif_significance
 
-Contents
-++++++++
 """
 
 from .. dl_import import dl_import
@@ -69,7 +69,7 @@ def local_clustering(g, weight=None, prop=None, undirected=True):
     prop : :class:`~graph_tool.VertexPropertyMap` or string, optional
         Vertex property map where results will be stored. If specified, this
         parameter will also be the return value.
-    undirected : bool (default: True)
+    undirected : bool (default: ``True``)
         Calculate the *undirected* clustering coefficient, if graph is directed
         (this option has no effect if the graph is undirected).
 
@@ -131,7 +131,7 @@ def local_clustering(g, weight=None, prop=None, undirected=True):
     return prop
 
 
-def global_clustering(g, weight=None, ret_counts=False):
+def global_clustering(g, weight=None, ret_counts=False, sampled=False, m=1000):
     r"""Return the global clustering coefficient.
 
     Parameters
@@ -143,15 +143,22 @@ def global_clustering(g, weight=None, ret_counts=False):
     ret_counts : ``boolean`` (optional, default: ``False``)
         If ``True`` the number of triangles and connected triples are also
         returned.
+    sampled : bool (default: ``False``)
+        If ``True`` a much faster, assymptotically exact, sampling estimate is
+        performed. In this case the, ``weight`` option is ignored.
+    m : int (default: ``1000``)
+        If ``sampled is True``, this will be the number of samples used for the
+        estimation.
 
     Returns
     -------
-    c : tuple of floats
-        Global clustering coefficient and standard deviation (jackknife method)
+    c : tuple of floats or float
+        Global clustering coefficient and standard deviation (jackknife method).
+        If ``sampled is True`` only the clustering coefficient is returned.
     triangles : `int` (if ``ret_counts is True``)
-        Number of triangles.
+        Number of triangles. Not returned if ``sampled is True``.
     triples : `int` (if ``ret_counts is True``)
-        Number of connected triples.
+        Number of connected triples. Not returned if ``sampled is True``.
 
     See Also
     --------
@@ -198,7 +205,10 @@ def global_clustering(g, weight=None, ret_counts=False):
 
     if g.is_directed():
         g = GraphView(g, directed=False, skip_properties=True)
-    c = _gt.global_clustering(g._Graph__graph, _prop("e", g, weight))
+    if not sampled:
+        c = _gt.global_clustering(g._Graph__graph, _prop("e", g, weight))
+    else:
+        return _gt.global_clustering_sampled(g._Graph__graph, m, _get_rng())
     if ret_counts:
         return c[:2], c[2], c[3]
     else:
@@ -351,9 +361,9 @@ def motifs(g, k, p=1.0, motif_list=None, return_maps=False):
     >>> g = gt.random_graph(1000, lambda: (5,5))
     >>> motifs, counts = gt.motifs(gt.GraphView(g, directed=False), 4)
     >>> print(len(motifs))
-    11
+    13
     >>> print(counts)
-    [116386, 392916, 443, 507, 2574, 1124, 741, 5, 5, 8, 2]
+    [115812, 390706, 642, 729, 2656, 1662, 811, 6, 16, 4, 2, 7, 12]
 
     References
     ----------
@@ -524,7 +534,7 @@ def motif_significance(g, k, n_shuffles=100, p=1.0, motif_list=None,
     >>> print(len(motifs))
     12
     >>> print(zscores)
-    [2.59252643351441, 2.5966529814390387, 2.3459237708258587, -1.0829180621127024, -1.3368754665984663, -2.33027728409781, -3.055817397993647, -0.1, -0.15, -0.19, -0.4, -0.01]
+    [0.9356448791848487, 0.8189579649509503, 0.2720861155829026, -0.5086069434054314, -1.091630710611107, -0.8379737597626044, 1.092607157633067, 0.87, 0.89, -0.34, -0.16, -0.01]
 
     References
     ----------
@@ -571,7 +581,7 @@ def motif_significance(g, k, n_shuffles=100, p=1.0, motif_list=None,
                 m_e[_graph_sig(m_temp[j])].append(len(s_ms) - 1)
 
     s_counts = [x / float(n_shuffles) for x in s_counts]
-    s_dev = [max(sqrt(x[0] / float(n_shuffles) - x[1] ** 2), 1) \
+    s_dev = [max((sqrt(x[0] / float(n_shuffles) - x[1] ** 2), 1)) \
               for x in zip(s_dev, s_counts)]
 
     list_hist = list(zip(s_ms, s_counts, s_dev))
