@@ -19,20 +19,19 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.dynamics`` - Dynamical processes
----------------------------------------------
+``graph_tool.dynamics``
+-----------------------
 
 This module contains implementations of some often-studied dynamical processes
 that take place on networks.
 
-Summary
-+++++++
-
 Discrete-time dynamics
 ======================
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
+   :template: class.rst
 
    DiscreteStateBase
    EpidemicStateBase
@@ -57,6 +56,8 @@ Continuous-time dynamics
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
+   :template: class.rst
 
    ContinuousStateBase
    KuramotoState
@@ -69,7 +70,7 @@ Contents
 
 from .. import _degree, _prop, Graph, GraphView, _get_rng, PropertyMap, \
     EdgePropertyMap, VertexPropertyMap, _check_prop_scalar
-from .. stats import label_self_loops
+from .. generation import label_self_loops
 import numpy
 import numpy.random
 import collections.abc
@@ -870,7 +871,7 @@ class BinaryThresholdState(DiscreteStateBase):
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.BinaryThresholdState(g, r=0.25)
            >>> ret = state.iterate_sync(niter=1000)
-           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
+           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
            ...               output="binary-threshold.pdf")
            <...>
 
@@ -951,7 +952,7 @@ class IsingGlauberState(DiscreteStateBase):
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.IsingGlauberState(g, beta=.05)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
-           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
+           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
            ...               output="glauber-ising.pdf")
            <...>
 
@@ -1121,7 +1122,7 @@ class IsingMetropolisState(DiscreteStateBase):
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.IsingMetropolisState(g, beta=.1)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
-           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
+           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
            ...               output="metropolis-ising.pdf")
            <...>
 
@@ -1414,7 +1415,7 @@ class KirmanState(DiscreteStateBase):
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.KirmanState(g)
            >>> ret = state.iterate_sync(niter=1000)
-           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
+           >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
            ...               output="kirman.pdf")
            <...>
 
@@ -1593,7 +1594,7 @@ class BooleanState(DiscreteStateBase):
            ...     ret = state.iterate_sync(niter=1)
            ...     l += 1
            >>> print("Period length:", l)
-           Period length: 3
+           Period length: 4
 
         """
 
