@@ -130,8 +130,8 @@ def mcmc_equilibrate(state, wait=1000, nbreaks=2, max_niter=numpy.inf,
         total_nattempts += nattempts
 
         if force_niter is not None:
-            max_S = max(S, max_S)
-            min_S = min(S, min_S)
+            max_S = max((S, max_S))
+            min_S = min((S, min_S))
             if niter >= force_niter:
                 break
         else:
@@ -380,8 +380,8 @@ class MulticanonicalState(object):
             h = array([1e-6] + list(h))
 
         h_mean = h.mean()
-        return min(h.min() / h_mean,
-                   h_mean / h.max())
+        return min((h.min() / h_mean,
+                    h_mean / h.max()))
 
     def get_posterior(self, N=None):
         "Get posterior probability."
