@@ -35,7 +35,7 @@ class UncertainBaseState(object):
     r"""Base state for uncertain network inference."""
 
     def __init__(self, g, nested=True, state_args={}, bstate=None,
-                 self_loops=False, init_empty=False, max_w=1 << 16):
+                 self_loops=False, init_empty=False, max_m=1 << 16):
 
         self.g = g
 
@@ -108,14 +108,14 @@ class UncertainBaseState(object):
         self.slist = Vector_size_t(init=edges[:,0])
         self.tlist = Vector_size_t(init=edges[:,1])
 
-        self.max_w = max_w
+        self.max_m = max_m
 
         init_q_cache()
 
     def __getstate__(self):
         return dict(g=self.g, nested=self.nbstate is not None,
                     bstate=(self.nbstate if self.nbstate is not None else self.bstate),
-                    self_loops=self.self_loops)
+                    self_loops=self.self_loops, max_m=self.max_m)
 
     def __setstate__(self, state):
         self.__init__(**state)
@@ -780,14 +780,14 @@ class MixedMeasuredBlockState(UncertainBaseState):
                 hs = [self.alpha, self.beta, self.mu, self.nu]
                 j = numpy.random.randint(len(hs))
 
-                f_dh = [max(0, hs[j] - hstep), hs[j] + hstep]
+                f_dh = [max((0, hs[j] - hstep)), hs[j] + hstep]
                 pf = 1./(f_dh[1] - f_dh[0])
 
                 old_hs = hs[j]
                 hs[j] = f_dh[0] + numpy.random.random() * (f_dh[1] - f_dh[0])
 
-                b_dh = [max(0, hs[j] - hstep), hs[j] + hstep]
-                pb = 1./min(1, hs[j])
+                b_dh = [max((0, hs[j] - hstep)), hs[j] + hstep]
+                pb = 1./min((1, hs[j]))
 
                 latent_edges = kwargs.get("entropy_args", {}).get("latent_edges", True)
                 density = False
@@ -884,8 +884,8 @@ class DynamicsBlockStateBase(UncertainBaseState):
             x = transform[1](x)
 
         if rg is not None:
-            mi = max(rg[0], x - step)
-            ma = min(rg[1], x + step)
+            mi = max((rg[0], x - step))
+            ma = min((rg[1], x + step))
         else:
             mi = x - step
             ma = x + step
@@ -894,8 +894,8 @@ class DynamicsBlockStateBase(UncertainBaseState):
         a = 0
         if rg is not None:
             a -= -log(ma - mi)
-            mi = max(rg[0], nx - step)
-            ma = min(rg[1], nx + step)
+            mi = max((rg[0], nx - step))
+            ma = min((rg[1], nx + step))
             a += -log(ma - mi)
 
         if transform is not None:
