@@ -19,14 +19,18 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.spectral`` - Spectral properties
----------------------------------------------
+``graph_tool.spectral``
+-----------------------
 
-Summary
-+++++++
+This module contains several linear operators based on network structure, which
+useful for spectral analysis.
+
+Sparse matrices
++++++++++++++++
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    adjacency
    laplacian
@@ -35,6 +39,14 @@ Summary
    modularity_matrix
    hashimoto
 
+Operator objects
+++++++++++++++++
+
+.. autosummary::
+   :nosignatures:
+   :toctree: autosummary
+   :template: class.rst
+
    AdjacencyOperator
    LaplacianOperator
    IncidenceOperator
@@ -42,13 +54,11 @@ Summary
    HashimotoOperator
    CompactHashimotoOperator
 
-Contents
-++++++++
 """
 
 from .. import _degree, _prop, Graph, GraphView, _limit_args, Vector_int64_t, \
     Vector_double
-from .. stats import label_self_loops
+from .. generation import label_self_loops
 import numpy
 import scipy.sparse
 import scipy.sparse.linalg
@@ -71,7 +81,7 @@ def adjacency(g, weight=None, vindex=None, operator=False, csr=True):
     weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
         Edge property map with the edge weights.
     vindex : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Vertex property map specifying the row/column indexes. If not provided, the
+        Vertex property map specifying the row/column indices. If not provided, the
         internal vertex index is used.
     operator : ``bool`` (optional, default: ``False``)
         If ``True``, a :class:`scipy.sparse.linalg.LinearOperator` subclass is
@@ -271,7 +281,7 @@ def laplacian(g, deg="out", norm=False, weight=None, r=1, vindex=None, operator=
         then this corresponds to the Bethe Hessian. (This parameter has an
         effect only for ``norm == False``.)
     vindex : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Vertex property map specifying the row/column indexes. If not provided, the
+        Vertex property map specifying the row/column indices. If not provided, the
         internal vertex index is used.
     operator : ``bool`` (optional, default: ``False``)
         If ``True``, a :class:`scipy.sparse.linalg.LinearOperator` subclass is
@@ -544,10 +554,10 @@ def incidence(g, vindex=None, eindex=None, operator=False, csr=True):
     g : :class:`~graph_tool.Graph`
         Graph to be used.
     vindex : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Vertex property map specifying the row indexes. If not provided, the
+        Vertex property map specifying the row indices. If not provided, the
         internal vertex index is used.
     eindex : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
-        Edge property map specifying the column indexes. If not provided, the
+        Edge property map specifying the column indices. If not provided, the
         internal edge index is used.
     operator : ``bool`` (optional, default: ``False``)
         If ``True``, a :class:`scipy.sparse.linalg.LinearOperator` subclass is
@@ -745,7 +755,7 @@ def transition(g, weight=None, vindex=None, operator=False, csr=True):
     weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
         Edge property map with the edge weights.
     vindex : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Vertex property map specifying the row/column indexes. If not provided,
+        Vertex property map specifying the row/column indices. If not provided,
         the internal vertex index is used.
     operator : ``bool`` (optional, default: ``False``)
         If ``True``, a :class:`scipy.sparse.linalg.LinearOperator` subclass is
@@ -932,7 +942,7 @@ def modularity_matrix(g, weight=None, vindex=None):
     weight : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
         Edge property map with the edge weights.
     index : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Vertex property map specifying the row/column indexes. If not provided, the
+        Vertex property map specifying the row/column indices. If not provided, the
         internal vertex index is used.
 
     Returns
@@ -1033,7 +1043,7 @@ def hashimoto(g, index=None, compact=False, operator=False, csr=True):
     g : :class:`~graph_tool.Graph`
         Graph to be used.
     index : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
-        Edge property map specifying the row/column indexes. If not provided, the
+        Edge property map specifying the row/column indices. If not provided, the
         internal edge index is used.
     compact : ``boolean`` (optional, default: ``False``)
         If ``True``, a compact :math:`2|V|\times 2|V|` version of the matrix is
