@@ -19,27 +19,24 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.stats`` - Miscellaneous statistics
------------------------------------------------
+``graph_tool.stats``
+--------------------
+
+This module contains miscellaneous statistical functions.
 
 Summary
 +++++++
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    vertex_hist
    edge_hist
    vertex_average
    edge_average
-   label_parallel_edges
-   label_self_loops
-   remove_labeled_edges
    distance_histogram
 
-Contents
-++++++++
-
 """
 
 from .. dl_import import dl_import
@@ -50,7 +47,6 @@ from .. generation import libgraph_tool_generation
 from numpy import *
 
 __all__ = ["vertex_hist", "edge_hist", "vertex_average", "edge_average",
-           "label_parallel_edges", "label_self_loops", "remove_labeled_edges",
            "distance_histogram"]
 
 
@@ -107,8 +103,8 @@ def vertex_hist(g, deg, bins=[0, 1], float_count=True):
     >>> from numpy.random import poisson
     >>> g = gt.random_graph(1000, lambda: (poisson(5), poisson(5)))
     >>> print(gt.vertex_hist(g, "out"))
-    [array([  5.,  32.,  85., 148., 152., 182., 160., 116.,  53.,  25.,  23.,
-            13.,   3.,   2.,   1.]), array([ 0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15],
+    [array([ 11.,  28.,  88., 141., 169., 165., 151., 111.,  60.,  42.,  20.,
+            10.,   3.,   1.]), array([ 0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14],
           dtype=uint64)]
     """
 
@@ -172,8 +168,7 @@ def edge_hist(g, eprop, bins=[0, 1], float_count=True):
     >>> eprop = g.new_edge_property("double")
     >>> eprop.get_array()[:] = random(g.num_edges())
     >>> print(gt.edge_hist(g, eprop, linspace(0, 1, 11)))
-    [array([485., 538., 502., 505., 474., 497., 544., 465., 492., 498.]), array([0. , 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1. ])]
-
+    [array([525., 504., 502., 502., 467., 499., 531., 471., 520., 479.]), array([0. , 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1. ])]
     """
 
     ret = libgraph_tool_stats.\
@@ -226,7 +221,7 @@ def vertex_average(g, deg):
     >>> from numpy.random import poisson
     >>> g = gt.random_graph(1000, lambda: (poisson(5), poisson(5)))
     >>> print(gt.vertex_average(g, "in"))
-    (4.986, 0.07323799560337517)
+    (5.028, 0.071240...)
     """
 
     if isinstance(deg, PropertyMap) and "string" in deg.value_type():
@@ -288,7 +283,7 @@ def edge_average(g, eprop):
     >>> eprop = g.new_edge_property("double")
     >>> eprop.get_array()[:] = random(g.num_edges())
     >>> print(gt.edge_average(g, eprop))
-    (0.5027850372071281, 0.004073940886690715)
+    (0.49683199099042286, 0.004095628750806015)
     """
 
     if "string" in eprop.value_type():
@@ -305,49 +300,6 @@ def edge_average(g, eprop):
     aa = sqrt((aa / count - a ** 2) / count)
     return a, aa
 
-
-def remove_labeled_edges(g, label):
-    """Remove every edge `e` such that `label[e] != 0`."""
-    u = GraphView(g, directed=True, reversed=g.is_reversed(),
-                  skip_properties=True)
-    libgraph_tool_stats.\
-          remove_labeled_edges(u._Graph__graph, _prop("e", g, label))
-
-
-def label_parallel_edges(g, mark_only=False, eprop=None):
-    r"""Label edges which are parallel, i.e, have the same source and target
-    vertices. For each parallel edge set :math:`PE`, the labelling starts from 0
-    to :math:`|PE|-1`. If `mark_only==True`, all parallel edges are simply
-    marked with the value 1. If the `eprop` parameter is given (a
-    :class:`~graph_tool.EdgePropertyMap`), the labelling is stored there."""
-    if eprop is None:
-        if mark_only:
-            eprop = g.new_edge_property("bool")
-        else:
-            eprop = g.new_edge_property("int32_t")
-    libgraph_tool_stats.\
-          label_parallel_edges(g._Graph__graph, _prop("e", g, eprop),
-                               mark_only)
-    return eprop
-
-
-def label_self_loops(g, mark_only=False, eprop=None):
-    """Label edges which are self-loops, i.e, the source and target vertices are
-    the same. For each self-loop edge set :math:`SL`, the labelling starts from 0
-    to :math:`|SL|-1`. If `mark_only == True`, self-loops are labeled with 1
-    and others with 0. If the `eprop` parameter is given
-    (a :class:`~graph_tool.EdgePropertyMap`), the labelling is stored there."""
-
-    if eprop is None:
-        if mark_only:
-            eprop = g.new_edge_property("bool")
-        else:
-            eprop = g.new_edge_property("int32_t")
-    libgraph_tool_stats.\
-          label_self_loops(g._Graph__graph, _prop("e", g, eprop),
-                           mark_only)
-    return eprop
-
 def distance_histogram(g, weight=None, bins=[0, 1], samples=None,
                        float_count=True):
     r"""
@@ -407,10 +359,11 @@ def distance_histogram(g, weight=None, bins=[0, 1], samples=None,
     >>> g = gt.random_graph(100, lambda: (3, 3))
     >>> hist = gt.distance_histogram(g)
     >>> print(hist)
-    [array([   0.,  300.,  862., 2195., 3850., 2518.,  175.]), array([0, 1, 2, 3, 4, 5, 6, 7], dtype=uint64)]
+    [array([   0.,  300.,  866., 2189., 3825., 2525.,  195.]), array([0, 1, 2, 3, 4, 5, 6, 7], dtype=uint64)]
     >>> hist = gt.distance_histogram(g, samples=10)
     >>> print(hist)
-    [array([  0.,  30.,  86., 213., 378., 262.,  21.]), array([0, 1, 2, 3, 4, 5, 6, 7], dtype=uint64)]
+    [array([  0.,  30.,  87., 221., 400., 236.,  16.]), array([0, 1, 2, 3, 4, 5, 6, 7], dtype=uint64)]
+
     """
 
     if samples is not None:
